@@ -1,6 +1,8 @@
-use solana_core::validator::ValidatorConfig;
-use solana_sdk::exit::Exit;
-use std::sync::{Arc, RwLock};
+use {
+    solana_core::validator::ValidatorConfig,
+    solana_sdk::exit::Exit,
+    std::sync::{Arc, RwLock},
+};
 
 pub fn safe_clone_config(config: &ValidatorConfig) -> ValidatorConfig {
     ValidatorConfig {
@@ -58,7 +60,6 @@ pub fn safe_clone_config(config: &ValidatorConfig) -> ValidatorConfig {
         poh_hashes_per_batch: config.poh_hashes_per_batch,
         no_wait_for_vote_to_start_leader: config.no_wait_for_vote_to_start_leader,
         accounts_shrink_ratio: config.accounts_shrink_ratio,
-        disable_epoch_boundary_optimization: config.disable_epoch_boundary_optimization,
     }
 }
 
